
#include <unistd.h>

#include <xcb/xcb.h>
#include <vlc/vlc.h>


int
main (int argc, char **argv)
{
  int screen_num;
  xcb_connection_t *conn;
  xcb_visualid_t visual = { 0 };
  xcb_window_t win_root, win_video;
  xcb_screen_t *screen = NULL;
  xcb_screen_iterator_t iter;
  uint32_t attributes[] = { 0, 1 }; /* black_pixel, override_redirect */
  uint16_t width, height;
  const uint32_t val_raised[] = { XCB_STACK_MODE_ABOVE };

  const char *vlc_argv[32] = { "vlc" };
  int vlc_argc = 1;
  libvlc_instance_t *core;
  libvlc_media_player_t *mp;
  libvlc_media_t *media;

  /* X11 */

  conn = xcb_connect (NULL, &screen_num);

  iter = xcb_setup_roots_iterator (xcb_get_setup (conn));
  for (; iter.rem; --screen_num, xcb_screen_next (&iter))
    if (!screen_num)
      screen = iter.data;

  attributes[0] = screen->black_pixel;
  visual        = screen->root_visual;
  win_root      = screen->root;
  width         = screen->width_in_pixels;
  height        = screen->height_in_pixels;

  win_video = xcb_generate_id (conn);
  xcb_create_window (conn, XCB_COPY_FROM_PARENT, win_video,
                     win_root, 0, 0, width, height, 0,
                     XCB_WINDOW_CLASS_INPUT_OUTPUT, visual,
                     XCB_CW_BACK_PIXEL | XCB_CW_OVERRIDE_REDIRECT,
                     attributes);
  xcb_flush (conn);

  /* VLC */

  vlc_argv[vlc_argc++] = "--no-stats";
  vlc_argv[vlc_argc++] = "--intf";
  vlc_argv[vlc_argc++] = "dummy";
  vlc_argv[vlc_argc++] = "--verbose";
  vlc_argv[vlc_argc++] = "4";
  vlc_argv[vlc_argc++] = "--ignore-config";
  vlc_argv[vlc_argc++] = "--reset-plugins-cache";
  vlc_argv[vlc_argc++] = "--no-media-library";
  vlc_argv[vlc_argc++] = "--no-one-instance";
  vlc_argv[vlc_argc++] = "--no-osd";
  vlc_argv[vlc_argc++] = "--no-video-title-show";
#if 0
  vlc_argv[vlc_argc++] = "--x11-display";
  vlc_argv[vlc_argc++] = ":0.0";
#endif /* 0 */
  vlc_argv[vlc_argc++] = "--vout";
  vlc_argv[vlc_argc++] = "x11";

  core = libvlc_new (vlc_argc, vlc_argv);
  mp = libvlc_media_player_new (core);
  libvlc_media_player_set_xwindow (mp, win_video);

  /* Play */

  media = libvlc_media_new_path (core, argv[1]);

  xcb_configure_window (conn, win_video,
                        XCB_CONFIG_WINDOW_STACK_MODE, val_raised);
  xcb_map_window (conn, win_video);
  xcb_flush (conn);

  libvlc_media_player_set_media (mp, media);
  libvlc_media_player_play (mp);

  usleep (2000000);

  /* Quit */

  xcb_unmap_window (conn, win_video);
  xcb_flush (conn);

  libvlc_media_player_stop (mp);
  libvlc_media_release (media);
  libvlc_media_player_release (mp);
  libvlc_release (core);

  xcb_destroy_window (conn, win_video);
  xcb_disconnect (conn);

  return 0;
}
